package com.vctgo.system.service;

import com.baomidou.mybatisplus.core.metadata.IPage;
import com.vctgo.system.domain.SysChildhoodManage;

import java.util.List;

/**
 * 幼儿管理对象Service接口
 *
 * @author wanglonghua
 * @date 2023-10-08
 */
public interface ISysChildhoodManageService
{
    /**
     * 查询幼儿管理对象
     *
     * @param id 幼儿管理对象主键
     * @return 幼儿管理对象
     */
    SysChildhoodManage selectSysChildhoodManageById(Long id);

    /**
     * 查询幼儿管理对象列表-分页
     *
     * @param sysChildhoodManage 幼儿管理对象
     * @return 幼儿管理对象集合
     */
    IPage<SysChildhoodManage> selectSysChildhoodManagePage(SysChildhoodManage sysChildhoodManage);
    /**
     * 查询幼儿管理对象列表
     *
     * @param sysChildhoodManage 幼儿管理对象
     * @return 幼儿管理对象集合
     */
    List<SysChildhoodManage> selectSysChildhoodManageList(SysChildhoodManage sysChildhoodManage);

    /**
     * 新增幼儿管理对象
     *
     * @param sysChildhoodManage 幼儿管理对象
     * @return 结果
     */
    int insertSysChildhoodManage(SysChildhoodManage sysChildhoodManage);

    /**
     * 修改幼儿管理对象
     *
     * @param sysChildhoodManage 幼儿管理对象
     * @return 结果
     */
    int updateSysChildhoodManage(SysChildhoodManage sysChildhoodManage);

    /**
     * 逻辑删除幼儿管理对象
     *
     * @param ids
     * @return 结果
     */
    int logicalDeleteSysChildhoodManageByIds(Long[] ids);

    /**
     * 批量删除幼儿管理对象
     *
     * @param ids 需要删除的幼儿管理对象主键集合
     * @return 结果
     */
    int deleteSysChildhoodManageByIds(Long[] ids);

    /**
     * 删除幼儿管理对象信息
     *
     * @param id 幼儿管理对象主键
     * @return 结果
     */
    int deleteSysChildhoodManageById(Long id);
}
